npTDMS API Reference
====================

Reading TDMS Files
------------------

.. module:: nptdms

.. autoclass:: TdmsFile
  :members:

  .. automethod:: __init__

.. autoclass:: TdmsObject
  :members:

Writing TDMS Files
------------------

.. autoclass:: TdmsWriter
  :members:

  .. automethod:: __init__

.. autoclass:: RootObject
  :members:

  .. automethod:: __init__

.. autoclass:: GroupObject
  :members:

  .. automethod:: __init__

.. autoclass:: ChannelObject
  :members:

  .. automethod:: __init__

Data Types for Property Values
------------------------------

.. module:: nptdms.types

.. autoclass:: Int8

.. autoclass:: Int16

.. autoclass:: Int32

.. autoclass:: Int64

.. autoclass:: Uint8

.. autoclass:: Uint16

.. autoclass:: Uint32

.. autoclass:: Uint64

.. autoclass:: SingleFloat

.. autoclass:: DoubleFloat

.. autoclass:: String

.. autoclass:: Boolean

.. autoclass:: TimeStamp

Indices and Tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
